@@ -11,10 +11,9 @@ use_cuda = torch.cuda.is_available()
 
 
 class FineTune:
-    r"""
-    Fine-tune methods to be applied to the individual model components.
+    r"""Fine-tune methods to be applied to the individual model components.
 
-    Note that they can also be used to "fine-tune" those components before
+    Note that they can also be used to "warm-up" those components before
     the joined training.
 
     There are 3 fine-tune/warm-up routines available:
@@ -47,7 +46,7 @@ class FineTune:
         self,
         loss_fn: Any,
         metric: Union[Metric, MultipleMetrics],
-        method: str,
+        method: Literal["binary", "regression", "multiclass"],
         verbose: int,
     ):
         self.loss_fn = loss_fn
@@ -251,12 +250,12 @@ class FineTune:
         for epoch in range(n_epochs):
             running_loss = 0.0
             with trange(steps, disable=self.verbose != 1) as t:
-                for batch_idx, (data, target) in zip(t, loader):
+                for batch_idx, (data, target, lds_weightt) in zip(t, loader):
                     t.set_description("epoch %i" % (epoch + 1))
                     X = data[model_name].cuda() if use_cuda else data[model_name]
                     y = (
                         target.view(-1, 1).float()
-                        if self.method != "multiclass"
+                        if self.method not in ["multiclass", "qregression"]
                         else target
                     )
                     y = y.cuda() if use_cuda else y
@@ -276,6 +275,8 @@ class FineTune:
                             score = self.metric(y_pred, y)
                         if self.method == "binary":
                             score = self.metric(torch.sigmoid(y_pred), y)
+                        if self.method == "qregression":
+                            score = self.metric(y_pred, y)
                         if self.method == "multiclass":
                             score = self.metric(F.softmax(y_pred, dim=1), y)
                         t.set_postfix(
