@@ -1,16 +1,25 @@
 import numpy as np
+import torch
 from tqdm import tqdm
 from torch import nn
+from torch.utils.data import TensorDataset
 from sklearn.model_selection import train_test_split
 
 from pytorch_widedeep.losses import (
+    L1Loss,
+    MSELoss,
     MSLELoss,
     RMSELoss,
     ZILNLoss,
     FocalLoss,
+    HuberLoss,
     RMSLELoss,
     TweedieLoss,
     QuantileLoss,
+    FocalR_L1Loss,
+    BayesianSELoss,
+    FocalR_MSELoss,
+    FocalR_RMSELoss,
 )
 from pytorch_widedeep.wdtypes import Dict, List, Optional, Transforms
 from pytorch_widedeep.training._wd_dataset import WideDeepDataset
@@ -20,6 +29,80 @@ from pytorch_widedeep.training._loss_and_obj_aliases import (
 )
 
 
+def tabular_train_val_split(
+    seed: int,
+    method: str,
+    X: np.ndarray,
+    y: np.ndarray,
+    X_val: Optional[np.ndarray] = None,
+    y_val: Optional[np.ndarray] = None,
+    val_split: Optional[float] = None,
+):
+    r"""
+    Function to create the train/val split for the BayesianTrainer where only
+    tabular data is used
+
+    Parameters
+    ----------
+    seed: int
+        random seed to be used during train/val split
+    method: str
+        'regression',  'binary' or 'multiclass'
+    X: np.ndarray
+        tabular dataset (categorical and continuous features)
+    y: np.ndarray
+    X_val: np.ndarray, Optional, default = None
+        Dict with the validation set, where the keys are the component names
+        (e.g: 'wide') and the values the corresponding arrays
+    y_val: np.ndarray, Optional, default = None
+
+    Returns
+    -------
+    train_set: ``TensorDataset``
+    eval_set: ``TensorDataset``
+    """
+
+    if X_val is not None:
+        assert (
+            y_val is not None
+        ), "if X_val is not None the validation target 'y_val' must also be specified"
+
+        train_set = TensorDataset(
+            torch.from_numpy(X),
+            torch.from_numpy(y),
+        )
+        eval_set = TensorDataset(
+            torch.from_numpy(X_val),
+            torch.from_numpy(y_val),
+        )
+    elif val_split is not None:
+        y_tr, y_val, idx_tr, idx_val = train_test_split(
+            y,
+            np.arange(len(y)),
+            test_size=val_split,
+            random_state=seed,
+            stratify=y if method != "regression" else None,
+        )
+        X_tr, X_val = X[idx_tr], X[idx_val]
+
+        train_set = TensorDataset(
+            torch.from_numpy(X_tr),
+            torch.from_numpy(y_tr),
+        )
+        eval_set = TensorDataset(
+            torch.from_numpy(X_val),
+            torch.from_numpy(y_val),
+        )
+    else:
+        train_set = TensorDataset(
+            torch.from_numpy(X),
+            torch.from_numpy(y),
+        )
+        eval_set = None
+
+    return train_set, eval_set
+
+
 def wd_train_val_split(  # noqa: C901
     seed: int,
     method: str,
@@ -32,6 +115,7 @@ def wd_train_val_split(  # noqa: C901
     val_split: Optional[float] = None,
     target: Optional[np.ndarray] = None,
     transforms: Optional[List[Transforms]] = None,
+    **lds_args,
 ):
     r"""
     Function to create the train/val split for a wide and deep model
@@ -66,18 +150,16 @@ def wd_train_val_split(  # noqa: C901
 
     Returns
     -------
-    train_set: WideDeepDataset
-        train ``WideDeepDataset`` object
-    eval_set: WideDeepDataset
-        validation ``WideDeepDataset`` object
+    train_set: ``WideDeepDataset``
+    eval_set: ``WideDeepDataset``
     """
 
     if X_val is not None:
         assert (
             X_train is not None
         ), "if the validation set is passed as a dictionary, the training set must also be a dictionary"
-        train_set = WideDeepDataset(**X_train, transforms=transforms)  # type: ignore
-        eval_set = WideDeepDataset(**X_val, transforms=transforms)  # type: ignore
+        train_set = WideDeepDataset(**X_train, transforms=transforms, **lds_args)  # type: ignore
+        eval_set = WideDeepDataset(**X_val, transforms=transforms, is_training=False)  # type: ignore
     elif val_split is not None:
         if not X_train:
             X_train = _build_train_dict(X_wide, X_tab, X_text, X_img, target)
@@ -109,12 +191,12 @@ def wd_train_val_split(  # noqa: C901
                 X_train["X_img"][idx_tr],
                 X_train["X_img"][idx_val],
             )
-        train_set = WideDeepDataset(**X_tr, transforms=transforms)  # type: ignore
-        eval_set = WideDeepDataset(**X_val, transforms=transforms)  # type: ignore
+        train_set = WideDeepDataset(**X_tr, transforms=transforms, **lds_args)  # type: ignore
+        eval_set = WideDeepDataset(**X_val, transforms=transforms, is_training=False)  # type: ignore
     else:
         if not X_train:
             X_train = _build_train_dict(X_wide, X_tab, X_text, X_img, target)
-        train_set = WideDeepDataset(**X_train, transforms=transforms)  # type: ignore
+        train_set = WideDeepDataset(**X_train, transforms=transforms, **lds_args)  # type: ignore
         eval_set = None
 
     return train_set, eval_set
@@ -141,9 +223,9 @@ def print_loss_and_metric(pb: tqdm, loss: float, score: Dict):
     Parameters
     ----------
     pb: tqdm
-        tqdm Object defined as trange(...)
+        tqdm object defined as trange(...)
     loss: float
-        loss value
+        Loss value
     score: Dict
         Dictionary where the keys are the metric names and the values are the
         corresponding values
@@ -184,9 +266,36 @@ def save_epoch_logs(epoch_logs: Dict, loss: float, score: Dict, stage: str):
     return epoch_logs
 
 
+def bayesian_alias_to_loss(loss_fn: str, **kwargs):
+    r"""Function that returns the corresponding loss function given an alias.
+    To be used with the ``BayesianTrainer``
+
+    Parameters
+    ----------
+    loss_fn: str
+        Loss name
+
+    Returns
+    -------
+    Object
+        loss function
+
+    Examples
+    --------
+    >>> from pytorch_widedeep.training._trainer_utils import bayesian_alias_to_loss
+    >>> loss_fn = bayesian_alias_to_loss(loss_fn="binary", weight=None)
+    """
+    if loss_fn == "binary":
+        return nn.BCEWithLogitsLoss(pos_weight=kwargs["weight"], reduction="sum")
+    if loss_fn == "multiclass":
+        return nn.CrossEntropyLoss(weight=kwargs["weight"], reduction="sum")
+    if loss_fn == "regression":
+        return BayesianSELoss()
+        # return BayesianRegressionLoss(noise_tolerance=kwargs["noise_tolerance"])
+
+
 def alias_to_loss(loss_fn: str, **kwargs):  # noqa: C901
-    r"""
-    Function that returns the corresponding loss function given an alias
+    r"""Function that returns the corresponding loss function given an alias
 
     Parameters
     ----------
@@ -214,9 +323,9 @@ def alias_to_loss(loss_fn: str, **kwargs):  # noqa: C901
     if loss_fn in _LossAliases.get("multiclass"):
         return nn.CrossEntropyLoss(weight=kwargs["weight"])
     if loss_fn in _LossAliases.get("regression"):
-        return nn.MSELoss()
+        return MSELoss()
     if loss_fn in _LossAliases.get("mean_absolute_error"):
-        return nn.L1Loss()
+        return L1Loss()
     if loss_fn in _LossAliases.get("mean_squared_log_error"):
         return MSLELoss()
     if loss_fn in _LossAliases.get("root_mean_squared_error"):
@@ -229,5 +338,13 @@ def alias_to_loss(loss_fn: str, **kwargs):  # noqa: C901
         return QuantileLoss()
     if loss_fn in _LossAliases.get("tweedie"):
         return TweedieLoss()
+    if loss_fn in _LossAliases.get("huber"):
+        return HuberLoss()
+    if loss_fn in _LossAliases.get("focalr_l1"):
+        return FocalR_L1Loss()
+    if loss_fn in _LossAliases.get("focalr_mse"):
+        return FocalR_MSELoss()
+    if loss_fn in _LossAliases.get("focalr_rmse"):
+        return FocalR_RMSELoss()
     if "focal_loss" in loss_fn:
         return FocalLoss(**kwargs)
