@@ -3,8 +3,8 @@ import os
 import numpy as np
 from gensim.utils import tokenize
 
-from ..wdtypes import *  # noqa: F403
-from .fastai_transforms import Vocab, Tokenizer
+from pytorch_widedeep.wdtypes import *  # noqa: F403
+from pytorch_widedeep.utils.fastai_transforms import Vocab, Tokenizer
 
 __all__ = ["simple_preprocess", "get_texts", "pad_sequences", "build_embeddings_matrix"]
 
@@ -45,7 +45,7 @@ def simple_preprocess(
     """
     tokens = [
         token
-        for token in tokenize(doc, lower=False, deacc=deacc, errors="ignore")
+        for token in tokenize(doc, lower=lower, deacc=deacc, errors="ignore")
         if min_len <= len(token) <= max_len and not token.startswith("_")
     ]
     return tokens
