@@ -14,6 +14,17 @@ from typing import (
     Generator,
     Collection,
 )
+
+# isort: off
+if sys.version_info >= (3, 8):
+    from typing import Literal
+else:
+    try:
+        from typing_extensions import Literal
+    except ModuleNotFoundError:
+        pass
+# isort: on
+
 from pathlib import PosixPath
 
 import torch
@@ -22,7 +33,6 @@ from torch.nn import Module
 from torch.optim.optimizer import Optimizer
 from torchvision.transforms import (
     Pad,
-    Scale,
     Lambda,
     Resize,
     Compose,
@@ -35,52 +45,79 @@ from torchvision.transforms import (
     RandomCrop,
     ToPILImage,
     ColorJitter,
+    PILToTensor,
     RandomApply,
     RandomOrder,
+    GaussianBlur,
     RandomAffine,
     RandomChoice,
+    RandomInvert,
+    RandomErasing,
+    RandomEqualize,
     RandomRotation,
+    RandomSolarize,
     RandomGrayscale,
-    RandomSizedCrop,
+    RandomPosterize,
+    ConvertImageDtype,
+    InterpolationMode,
+    RandomPerspective,
     RandomResizedCrop,
+    RandomAutocontrast,
     RandomVerticalFlip,
     LinearTransformation,
     RandomHorizontalFlip,
+    RandomAdjustSharpness,
 )
 from torch.optim.lr_scheduler import _LRScheduler
 from torch.utils.data.dataloader import DataLoader
 
 from pytorch_widedeep.models import WideDeep
-from pytorch_widedeep.models.tabnet.sparsemax import Entmax15, Sparsemax
+from pytorch_widedeep.models.tabular.tabnet.sparsemax import (
+    Entmax15,
+    Sparsemax,
+)
+from pytorch_widedeep.bayesian_models._base_bayesian_model import (
+    BaseBayesianModel,
+)
 
 ListRules = Collection[Callable[[str], str]]
 Tokens = Collection[Collection[str]]
 Transforms = Union[
-    CenterCrop,
-    ColorJitter,
-    Compose,
-    FiveCrop,
-    Grayscale,
-    Lambda,
-    LinearTransformation,
-    Normalize,
     Pad,
-    RandomAffine,
-    RandomApply,
-    RandomChoice,
-    RandomCrop,
-    RandomGrayscale,
-    RandomHorizontalFlip,
-    RandomOrder,
-    RandomResizedCrop,
-    RandomRotation,
-    RandomSizedCrop,
-    RandomVerticalFlip,
+    Lambda,
     Resize,
-    Scale,
+    Compose,
     TenCrop,
-    ToPILImage,
+    FiveCrop,
     ToTensor,
+    Grayscale,
+    Normalize,
+    CenterCrop,
+    RandomCrop,
+    ToPILImage,
+    ColorJitter,
+    PILToTensor,
+    RandomApply,
+    RandomOrder,
+    GaussianBlur,
+    RandomAffine,
+    RandomChoice,
+    RandomInvert,
+    RandomErasing,
+    RandomEqualize,
+    RandomRotation,
+    RandomSolarize,
+    RandomGrayscale,
+    RandomPosterize,
+    ConvertImageDtype,
+    InterpolationMode,
+    RandomPerspective,
+    RandomResizedCrop,
+    RandomAutocontrast,
+    RandomVerticalFlip,
+    LinearTransformation,
+    RandomHorizontalFlip,
+    RandomAdjustSharpness,
 ]
 LRScheduler = _LRScheduler
 ModelParams = Generator[Tensor, Tensor, Tensor]
